@@ -11,7 +11,10 @@ import torch
 from ase import Atoms
 from ase.optimize import BFGS
 import ase.calculators.calculator
-from ..batch_opt.ANI2xt import ANI2xt
+try:
+    from ..batch_opt.ANI2xt import ANI2xt
+except:
+    pass
 import torchani
 from openbabel import pybel
 
