@@ -17,7 +17,7 @@ import ase.calculators.calculator
 try:
     from ..batch_opt.ANI2xt import ANI2xt
 except:
-    warnings.warn("ANI2xt is not available")
+    pass
 import torchani
 
 
