@@ -12,7 +12,7 @@ import ase.calculators.calculator
 try:
     from .batch_opt.ANI2xt import ANI2xt
 except:
-    warnings.warn("ANI2xt is not installed")
+    pass
 import torchani
 from openbabel import pybel
 from tqdm import tqdm
